from dataclasses import dataclass


@dataclass(frozen=True, order=True)
class SfwData:
    wave: str = "wave"
    wink: str = "wink"
    tea: str = "tea"
    bonk: str = "bonk"
    punch: str = "punch"
    poke: str = "poke"
    bully: str = "bully"
    pat: str = "pat"
    kiss: str = "kiss"
    kick: str = "kick"
    blush: str = "blush"
    feed: str = "feed"
    smug: str = "smug"
    hug: str = "hug"
    cuddle: str = "cuddle"
    cry: str = "cry"
    cringe: str = "cringe"
    slap: str = "five"
    glomp: str = "glomp"
    happy: str = "happy"
    hold: str = "hold"
    nom: str = "nom"
    smile: str = "smile"
    throw: str = "throw"
    lick: str = "lick"
    bite: str = "bite"
    dance: str = "dance"
    boop: str = "boop"
    sleep: str = "sleep"
    like: str = "like"
    kill: str = "kill"
    tickle: str = "tickle"
    nosebleed: str = "nosebleed"
    threaten: str = "threaten"
    depression: str = "depression"
    wolf_arts: str = "wolf_arts"
    jahy_arts: str = "jahy_arts"
    neko_arts: str = "neko_arts"
    coffee_arts: str = "coffee_arts"
    wallpaper: str = "wallpaper"
    mobile_wallpaper: str = "mobileWallpaper"
