from dataclasses import dataclass

@dataclass(frozen=True, order=True)
class NsfwData:
    ass: str = "ass"
    anal: str = "anal"
    bdsm: str = "bdsm"
    classic: str = "classic"
    cum: str = "cum"
    creampie: str = "creampie"
    manga: str = "manga"
    femdom: str = "femdom"
    hentai: str = "hentai"
    incest: str = "incest"
    masturbation: str = "masturbation"
    public: str = "public"
    ero: str = "ero"
    orgy: str = "orgy"
    elves: str = "elves"
    yuri: str = "yuri"
    pantsu: str = "pantsu"
    pussy: str = "pussy"
    glasses: str = "glasses"
    cuckold: str = "cuckold"
    blowjob: str = "blowjob"
    boobjob: str = "boobjob"
    handjob: str = "handjob"
    footjob: str = "footjob"
    boobs: str = "boobs"
    thighs: str = "thighs"
    ahegao: str = "ahegao"
    uniform: str = "uniform"
    gangbang: str = "gangbang"
    tentacles: str = "tentacles"
    gif: str = "gif"
    nsfw_neko: str = "nsfwNeko"
    nsfw_mobile_wallpaper: str = "nsfwMobileWallpeper"
    zettai_ryouiki: str = "zettaiRyouiki"
